@@ -7,6 +7,7 @@ except ImportError:
     import pickle
 import getpass
 import logging
+import os.path
 import sys
 import threading
 
@@ -19,6 +20,7 @@ from django.core.servers import basehttp
 from django.test.client import Client
 from django.test import TestCase
 from django.utils.encoding import smart_unicode
+from django.utils import simplejson
 
 from sentry import settings
 from sentry.helpers import transform
@@ -226,7 +228,8 @@ class SentryTestCase(TestCase):
         try:
             Message.objects.get(id=999999989)
         except Message.DoesNotExist, exc:
-            get_client().create_from_exception(exc)
+            error = get_client().create_from_exception(exc)
+            self.assertTrue(error.data.get('__sentry__', {}).get('exc'))
         else:
             self.fail('Unable to create `Message` entry.')
 
@@ -238,7 +241,6 @@ class SentryTestCase(TestCase):
         else:
             self.fail('Unable to create `Message` entry.')
 
-        
         self.assertEquals(Message.objects.count(), 2)
         self.assertEquals(GroupedMessage.objects.count(), 2)
         last = Message.objects.all().order_by('-id')[0:1].get()
@@ -616,9 +618,6 @@ class RemoteSentryTest(TestCase):
 
     def testCorrectData(self):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40}
-        data = {
-            
-        }
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
             'key': settings.KEY,
@@ -629,6 +628,36 @@ class RemoteSentryTest(TestCase):
         self.assertEquals(instance.server_name, 'not_dcramer.local')
         self.assertEquals(instance.level, 40)
 
+    def testUngzippedData(self):
+        kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40}
+        resp = self.client.post(reverse('sentry-store'), {
+            'data': base64.b64encode(pickle.dumps(transform(kwargs))),
+            'key': settings.KEY,
+        })
+        self.assertEquals(resp.status_code, 200)
+        instance = Message.objects.get()
+        self.assertEquals(instance.message, 'hello')
+        self.assertEquals(instance.server_name, 'not_dcramer.local')
+        self.assertEquals(instance.level, 40)
+
+    def testByteSequence(self):
+        """
+        invalid byte sequence for encoding "UTF8": 0xedb7af
+        """
+        fname = os.path.join(os.path.dirname(__file__), 'fixtures/encode_error.json')
+        kwargs = simplejson.load(open(fname))
+        
+        resp = self.client.post(reverse('sentry-store'), {
+            'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
+            'key': settings.KEY,
+        })
+        self.assertEquals(resp.status_code, 200)
+        instance = Message.objects.get()
+        self.assertEquals(instance.message, 'hello')
+        self.assertEquals(instance.server_name, 'localhost')
+        self.assertEquals(instance.level, 40)
+        self.assertTrue(instance.data['__sentry__']['exc'])
+
     # def testProcess(self):
     #     self.start_test_server()
     #     SentryClient.process(message='hello')
@@ -789,3 +818,15 @@ class SentryClientTest(TestCase):
         self.assertEquals(_foo[''].levelno, client.default_level)
         self.assertEquals(_foo[''].class_name, 'Exception')
 
+class SentryManageTest(TestCase):
+    fixtures = ['sentry/tests/fixtures/cleanup.json']
+    
+    def test_cleanup_sentry(self):
+        from sentry.management.commands.cleanup_sentry import Command
+        
+        self.assertEquals(Message.objects.count(), 10)
+        
+        command = Command()
+        command.handle(days=1)
+        
+        self.assertEquals(Message.objects.count(), 0)
\ No newline at end of file
