@@ -17,8 +17,9 @@ from django.conf import settings as dj_settings
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
 from django.db.models import Count
-from django.http import HttpResponse, HttpResponseForbidden, HttpResponseRedirect
-from django.shortcuts import render_to_response
+from django.http import HttpResponse, HttpResponseBadRequest, \
+    HttpResponseForbidden, HttpResponseRedirect
+from django.shortcuts import render_to_response, get_object_or_404
 from django.template.loader import render_to_string
 from django.utils import simplejson
 from django.utils.datastructures import SortedDict
@@ -104,7 +105,17 @@ def index(request):
         select={
             'score': GroupedMessage.get_score_clause(),
         }
-    ).order_by('-score', '-last_seen').distinct()
+    )
+
+    sort = request.GET.get('sort')
+    if sort == 'date':
+        message_list = message_list.order_by('-last_seen')
+    elif sort == 'new':
+        message_list = message_list.order_by('-first_seen')
+    else:
+        sort = 'priority'
+        message_list = message_list.order_by('-score', '-last_seen').distinct()
+
     
     any_filter = False
     for filter_ in filters:
@@ -115,22 +126,38 @@ def index(request):
     
     today = datetime.datetime.now()
 
-    if not any_filter and page == 1:
-        realtime = True
-    else:
-        realtime = False
+    has_realtime = page == 1
     
     return render_to_response('sentry/index.html', locals())
 
 @login_required
 def ajax_handler(request):
     op = request.REQUEST.get('op')
+
     if op == 'poll':
+        filters = []
+        for filter_ in get_filters():
+            filters.append(filter_(request))
+
         message_list = GroupedMessage.objects.extra(
             select={
                 'score': GroupedMessage.get_score_clause(),
             }
-        ).order_by('-score', '-last_seen')
+        )
+        
+        sort = request.GET.get('sort')
+        if sort == 'date':
+            message_list = message_list.order_by('-last_seen')
+        elif sort == 'new':
+            message_list = message_list.order_by('-first_seen')
+        else:
+            sort = 'priority'
+            message_list = message_list.order_by('-score', '-last_seen').distinct()
+        
+        for filter_ in filters:
+            if not filter_.is_set():
+                continue
+            message_list = filter_.get_query_set(message_list)
         
         data = [
             (m.pk, {
@@ -159,6 +186,8 @@ def ajax_handler(request):
                 'html': render_to_string('sentry/partial/_group.html', {'group': m}),
                 'count': m.times_seen,
             }) for m in [group]]
+    else:
+        return HttpResponseBadRequest()
         
     response = HttpResponse(simplejson.dumps(data))
     response['Content-Type'] = 'application/json'
@@ -166,7 +195,7 @@ def ajax_handler(request):
 
 @login_required
 def group(request, group_id):
-    group = GroupedMessage.objects.get(pk=group_id)
+    group = get_object_or_404(GroupedMessage, pk=group_id)
 
     message_list = group.message_set.all()
     
@@ -237,4 +266,4 @@ def store(request):
 
     GroupedMessage.objects.from_kwargs(**data)
     
-    return HttpResponse()
\ No newline at end of file
+    return HttpResponse()
